@@ -16,7 +16,7 @@ fn uses_error_flag() -> bool {
     match target_os.as_str() {
         "freebsd" | "macos" => true,
 
-        "linux" => matches!(target_arch.as_str(), "mips" | "mips64"),
+        "linux" | "android" => matches!(target_arch.as_str(), "mips" | "mips64"),
 
         _ => panic!("Unsupported OS"),
     }
